@@ -273,7 +273,11 @@ def server_tengine(version='2.0.3', user='webuser', tornado=True,process=1,conne
 
     run('chkconfig --level 35 nginx off')
 
-    run('wget http://tengine.taobao.org/download/tengine-{0}.tar.gz -O /tmp/tengine-{0}.tar.gz'.format(version))
+
+    if version:
+        run('wget http://tengine.taobao.org/download/tengine-{0}.tar.gz -O /tmp/tengine-{0}.tar.gz'.format(version))
+    else:
+        cmd_git('/tmp/tengine','https://github.com/nextoa/tengine.git')
 
     io_slowlog('nginx', user=user)
     io_aircache('nginx', size=1)
@@ -283,7 +287,10 @@ def server_tengine(version='2.0.3', user='webuser', tornado=True,process=1,conne
 
     with cd('/tmp'):
         run('tar -xvzpf tengine-{0}.tar.gz'.format(version))
-        with cd('/tmp/tengine-{0}'.format(version)):
+
+        real_path = '/tmp/tengine-{0}'.format(version) if version else '/tmp/tengine'
+
+        with cd(real_path):
 
             if tornado:
                 run('./configure --prefix=/usr/local --user={0} --group={0} --conf-path=/etc/nginx  --sbin-path=/usr/local/sbin '
